@@ -1,6 +1,6 @@
 =head1 NAME
 
-SVG::ChristmasTree
+SVG::ChristmasTree - Perl extension to draw Christmas trees with SVG
 
 =head1 DESCRIPTION
 
@@ -34,7 +34,7 @@ use Math::Trig qw[deg2rad tan];
 
 with 'MooseX::Getopt';
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 # Constants that we haven't made into attributes yet
 use constant {
